@@ -21,8 +21,12 @@ eval {
 ############################################################################################################
 $dri->add_registry('EURid',{clid=>$CLID});
 
-## This connects to .EU OT&E server
-my $rc=$dri->target('EURid')->new_current_profile('profile1','Net::DRI::Transport::Socket',[{log_fh=>\*STDERR,defer=>0,socktype=>'ssl',remote_host=>'epp.registry.tryout.eu',remote_port=>33123,ssl_key_file=>'privkey.pem',ssl_cert_file=>'cacert.pem',ssl_ca_file=>'cacert.pem',ssl_cipher_list=>'TLSv1',protocol_connection=>'Net::DRI::Protocol::EPP::Connection',protocol_version=>1,client_login=>$CLID,client_password=>$PASS}],'Net::DRI::Protocol::EPP::Extensions::EURid',['1.0',['Net::DRI::Protocol::EPP::Extensions::EURid::Sunrise']]);
+my $file='results-'.time().'.log';
+open(my $fh,'>>',$file) || die $!;
+print "Dumping XML exchange to $file\n";
+
+## This connects to .EU server for tests
+my $rc=$dri->target('EURid')->new_current_profile('profile1','Net::DRI::Transport::Socket',[{log_fh=>$fh,defer=>0,socktype=>'ssl',remote_host=>'epp.registry.tryout.eu',remote_port=>33123,ssl_cipher_list=>'TLSv1',protocol_connection=>'Net::DRI::Protocol::EPP::Connection',protocol_version=>1,client_login=>$CLID,client_password=>$PASS}],'Net::DRI::Protocol::EPP::Extensions::EURid',['1.0',['Net::DRI::Protocol::EPP::Extensions::EURid::Sunrise']]);
 
 die($rc) unless $rc->is_success(); ## Here we catch all errors during setup of transport, such as authentication errors
 
@@ -107,11 +111,12 @@ print "Contact2 deleted successfully" if $rc->is_success();
 $rc=$dri->contact_delete($c3);
 print "Contact3 deleted successfully" if $rc->is_success();
 
+close($fh);
 };
 
 if ($@)
 { 
- print "\n\nAN ERROR happened !!!\n";
+ print "\n\nAn EXCEPTION happened !\n";
  if (ref($@))
  {
   $@->print();
@@ -121,7 +126,7 @@ if ($@)
  }
 } else
 {
- print "\n\nNo error";
+ print "\n\nNo exception happened";
 }
 
 print "\n";
