@@ -24,7 +24,7 @@ use DateTime::Duration;
 use DateTime;
 use Net::DRI::Exception;
 
-our $VERSION=do { my @r=(q$Revision: 1.4 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
+our $VERSION=do { my @r=(q$Revision: 1.5 $=~/\d+/g); sprintf("%d".".%02d" x $#r, @r); };
 
 =pod
 
@@ -82,7 +82,7 @@ sub transport_protocol_compatible
  my $tn=$to->name();
 
  return 1 if (($pn eq 'RRP') && ($tn eq 'socket_inet'));
- return undef;
+ return;
 }
 
 ######################################################################################
@@ -109,10 +109,10 @@ sub domain_operation_needs_is_mine
  my ($self,$ndr,$domain,$op)=@_;
  ($domain,$op)=($ndr,$domain) unless (defined($ndr) && $ndr && (ref($ndr) eq 'Net::DRI::Registry'));
 
- return undef unless defined($op);
+ return unless defined($op);
 
  return 1 if ($op=~m/^(?:renew|update|delete)$/);
- return undef;
+ return;
 }
 
 ## Transfer operations are not possible
